%define upstream_name    Statistics-CaseResampling
%define upstream_version 0.16

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 1

Summary:    Efficient resampling and calculation of medians with confidence intervals
License:    GPLv1+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/Statistics/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(List::Util)
BuildRequires: perl-devel
%description
The purpose of this (XS) module is to calculate the median (or in principle
also other statistics) with confidence intervals on a sample. To do that,
it uses a technique called bootstrapping. In a nutshell, it resamples the
sample a lot of times and for each resample, it calculates the median. From
the distribution of medians, it then calculates the confidence limits.

In order to implement the confidence limit calculation, various other
functions had to be implemented efficiently (both algorithmically efficient
and done in C). These functions may be useful in their own right and are
thus exposed to Perl. Most notably, this exposes a median (and general
selection) algorithm that works in linear time as opposed to the trivial
implementation that requires 'O(n*log(n))'.

Random numbers
    The resampling involves drawing *many* random numbers. Therefore, the
    module comes with an embedded Mersenne twister (taken from
    'Math::Random::MT').

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor

%make_build

%check
%make_build test

%install
%make_install

%files
%doc Changes META.json META.yml MYMETA.yml README
%{_mandir}/man3/*
%perl_vendorarch/*

%changelog
* Fri May 23 2025 tv <tv> 0.160.0-1.mga10
+ Revision: 2186012
- update to 0.16

* Thu Aug 22 2024 neoclust <neoclust> 0.150.0-11.mga10
+ Revision: 2088220
- Rebuild against new perl

* Thu Nov 30 2023 tv <tv> 0.150.0-10.mga10
+ Revision: 2011607
- Rebuild for perl-5.38

* Tue Jun 07 2022 umeabot <umeabot> 0.150.0-9.mga9
+ Revision: 1862422
- Rebuild for Perl 5.36

* Thu Mar 17 2022 umeabot <umeabot> 0.150.0-8.mga9
+ Revision: 1796028
- Mageia 9 Mass Rebuild

* Mon May 24 2021 umeabot <umeabot> 0.150.0-7.mga9
+ Revision: 1727123
- Rebuild for perl 5.34

* Wed Jun 17 2020 umeabot <umeabot> 0.150.0-6.mga8
+ Revision: 1595268
- Rebuild for perl 5.32

* Sat Feb 15 2020 umeabot <umeabot> 0.150.0-5.mga8
+ Revision: 1529149
- Mageia 8 Mass Rebuild

* Tue Aug 27 2019 tv <tv> 0.150.0-4.mga8
+ Revision: 1433194
- rebuild with perl-5.30

* Fri Sep 21 2018 umeabot <umeabot> 0.150.0-3.mga7
+ Revision: 1293764
- Mageia 7 Mass Rebuild

* Wed Aug 08 2018 pterjan <pterjan> 0.150.0-2.mga7
+ Revision: 1250140
- Rebuild for perl 5.28

* Thu Jul 12 2018 tv <tv> 0.150.0-1.mga7
+ Revision: 1243233
- imported package perl-Statistics-CaseResampling

